@@ -1,3 +1,10 @@
+#
+# SPDX-FileCopyrightText: Copyright (c) 2025 provide.io llc. All rights reserved.
+# SPDX-License-Identifier: Apache-2.0
+#
+
+"""TODO: Add module docstring."""
+
 from abc import ABC, abstractmethod
 from typing import Any
 
@@ -24,3 +31,6 @@ class BaseCapability(ABC):
         provider's configuration schema.
         """
         raise NotImplementedError
+
+
+# 🐍🏗️🔚
