@@ -1,17 +1,17 @@
-"""
-Pyvider CLI Package
+#
+# SPDX-FileCopyrightText: Copyright (c) 2025 provide.io llc. All rights reserved.
+# SPDX-License-Identifier: Apache-2.0
+#
+
+"""Pyvider CLI Package
 ==================
-This module assembles the main CLI application.
-"""
+This module assembles the main CLI application."""
 
-# 1. Import the foundational 'cli' group object from main.
-# 2. Import the command objects (groups and commands) from their modules.
 from pyvider.cli.components_commands import components
 from pyvider.cli.config_commands import config
 from pyvider.cli.install_command import install_command
 from pyvider.cli.launch_context_command import launch_context_cmd
 from pyvider.cli.main import cli
-from pyvider.cli.prep_commands import prep
 from pyvider.cli.provide_command import provide_cmd
 
 # 3. Explicitly attach the commands to the main cli group.
@@ -19,7 +19,6 @@ cli.add_command(components)
 cli.add_command(config)
 cli.add_command(install_command)
 cli.add_command(launch_context_cmd)
-cli.add_command(prep)
 cli.add_command(provide_cmd)
 
 
@@ -35,3 +34,5 @@ def main() -> None:
 
 # 5. Expose the fully assembled 'cli' object and main function for entry points.
 __all__ = ["cli", "main"]
+
+# 🐍🏗️🔚
