@@ -1,6 +1,9 @@
-"""
-The canonical entry point for the Pyvider CLI application.
-"""
+#
+# SPDX-FileCopyrightText: Copyright (c) 2025 provide.io llc. All rights reserved.
+# SPDX-License-Identifier: Apache-2.0
+#
+
+"""The canonical entry point for the Pyvider CLI application."""
 
 import asyncio
 
@@ -28,3 +31,5 @@ def main() -> None:
 
 if __name__ == "__main__":
     main()
+
+# 🐍🏗️🔚
