@@ -1,4 +1,10 @@
-# pyvider/common/__init__.py
+#
+# SPDX-FileCopyrightText: Copyright (c) 2025 provide.io llc. All rights reserved.
+# SPDX-License-Identifier: Apache-2.0
+#
+
+"""TODO: Add module docstring."""
+
 from pyvider.common.operation_context import (
     OperationContext,
     get_current_operation,
@@ -10,3 +16,5 @@ __all__ = [
     "get_current_operation",
     "operation_context",
 ]
+
+# 🐍🏗️🔚
