@@ -1,14 +1,15 @@
-# pyvider/common/operation_context.py
-"""
-Manages the operational context for CTY type and value processing.
-"""
+#
+# SPDX-FileCopyrightText: Copyright (c) 2025 provide.io llc. All rights reserved.
+# SPDX-License-Identifier: Apache-2.0
+#
 
+"""Manages the operational context for CTY type and value processing."""
+
+from collections.abc import Generator
 import contextlib
 from contextvars import ContextVar
 from enum import Enum, auto
 
-from provide.foundation import logger
-
 
 class OperationContext(Enum):
     """
@@ -36,12 +37,13 @@ def get_current_operation() -> OperationContext:
 
 
 @contextlib.contextmanager
-def operation_context(context: OperationContext) -> None:
+def operation_context(context: OperationContext) -> Generator[None, None, None]:
     """A context manager to temporarily set the CTY operational context."""
-    logger.debug(f"🧰🔄📊 Pushing operation context: {context.name}")
     token = _current_operation_context.set(context)
     try:
         yield
     finally:
         _current_operation_context.reset(token)
-        logger.debug(f"🧰🔄📊 Popped operation context, restored to: {_current_operation_context.get().name}")
+
+
+# 🐍🏗️🔚
