@@ -1,4 +1,9 @@
-# pyvider/common/utils/availability.py
+#
+# SPDX-FileCopyrightText: Copyright (c) 2025 provide.io llc. All rights reserved.
+# SPDX-License-Identifier: Apache-2.0
+#
+
+"""Utility module for checking library availability."""
 
 from provide.foundation import logger
 
@@ -7,9 +12,11 @@ try:
 
     HAS_MSGPACK = importlib.util.find_spec("msgpack") is not None
     if HAS_MSGPACK:
-        logger.info("📦 msgpack library loaded successfully.")
+        logger.debug("✅ msgpack library is available")
     else:
         logger.warning("⚠️ msgpack library not found. msgpack features will be unavailable.")
 except Exception as e:
     HAS_MSGPACK = False
     logger.error(f"❌ Error checking msgpack availability: {e}")
+
+# 🐍🏗️🔚
