@@ -1,8 +1,10 @@
-# pyvider/ephemerals/__init__.py
-"""
-This package defines the core abstractions for implementing ephemeral resources,
-which are temporary, stateful components like API clients or database connections.
-"""
+#
+# SPDX-FileCopyrightText: Copyright (c) 2025 provide.io llc. All rights reserved.
+# SPDX-License-Identifier: Apache-2.0
+#
+
+"""This package defines the core abstractions for implementing ephemeral resources,
+which are temporary, stateful components like API clients or database connections."""
 
 from pyvider.ephemerals.base import BaseEphemeralResource
 from pyvider.ephemerals.context import EphemeralResourceContext
@@ -13,3 +15,5 @@ __all__ = [
     "EphemeralResourceContext",
     "register_ephemeral_resource",
 ]
+
+# 🐍🏗️🔚
