@@ -1,7 +1,9 @@
 #
-# pyvider/ephemerals/decorators.py
+# SPDX-FileCopyrightText: Copyright (c) 2025 provide.io llc. All rights reserved.
+# SPDX-License-Identifier: Apache-2.0
 #
 
+"""TODO: Add module docstring."""
 
 from collections.abc import Callable
 
@@ -29,4 +31,4 @@ def register_ephemeral_resource(name: str) -> Callable[[type], type]:
     return decorator
 
 
-# 🐍🏗️
+# 🐍🏗️🔚
