@@ -1,7 +1,10 @@
 #
-# pyvider/exceptions/foundation.py
+# SPDX-FileCopyrightText: Copyright (c) 2025 provide.io llc. All rights reserved.
+# SPDX-License-Identifier: Apache-2.0
 #
 
+"""TODO: Add module docstring."""
+
 
 class PyviderError(Exception):
     """Base class for all Pyvider errors."""
@@ -43,4 +46,4 @@ class UnsupportedTypeError(PyviderError):
         super().__init__(f"Unsupported type encountered: '{type_name}'.")
 
 
-# 🐍🏗
+# 🐍🏗️🔚
