@@ -1,4 +1,10 @@
-# pyvider/exceptions/serialization.py
+#
+# SPDX-FileCopyrightText: Copyright (c) 2025 provide.io llc. All rights reserved.
+# SPDX-License-Identifier: Apache-2.0
+#
+
+"""TODO: Add module docstring."""
+
 from typing import Any
 
 from pyvider.exceptions.base import ConversionError
@@ -36,3 +42,6 @@ class DeserializationError(ConversionError):
         super().__init__(full_message, source_value=source_value, target_type=type_name)
         self.type_name = type_name
         self.detail = detail
+
+
+# 🐍🏗️🔚
