@@ -1,13 +1,12 @@
 #
-# pyvider/functions/__init__.py
+# SPDX-FileCopyrightText: Copyright (c) 2025 provide.io llc. All rights reserved.
+# SPDX-License-Identifier: Apache-2.0
 #
 
-"""
-Pyvider Functions Module
+"""Pyvider Functions Module
 
 This module provides the core infrastructure for implementing and registering
-Terraform functions in Pyvider providers.
-"""
+Terraform functions in Pyvider providers."""
 
 from pyvider.functions.adapters import function_to_dict
 from pyvider.functions.base import (
@@ -26,3 +25,5 @@ __all__ = [
     "function_to_dict",
     "register_function",
 ]
+
+# 🐍🏗️🔚
