@@ -1,3 +1,10 @@
+#
+# SPDX-FileCopyrightText: Copyright (c) 2025 provide.io llc. All rights reserved.
+# SPDX-License-Identifier: Apache-2.0
+#
+
+"""TODO: Add module docstring."""
+
 from collections.abc import Callable
 from typing import Any
 
@@ -11,6 +18,7 @@ def register_function(
     description: str = "",
     param_descriptions: dict[str, str] | None = None,
     deprecation_message: str = "",
+    test_only: bool = False,
 ) -> Callable[[Callable[..., Any]], Callable[..., Any]]:
     """
     Decorator to register a function and associate it with a capability.
@@ -19,6 +27,7 @@ def register_function(
     def decorator(func: Callable[..., Any]) -> Callable[..., Any]:
         func._is_registered_function = True  # type: ignore
         func._registered_name = name  # type: ignore
+        func._is_test_only = test_only  # type: ignore
         if component_of:
             func._parent_capability = component_of  # type: ignore
 
@@ -32,10 +41,18 @@ def register_function(
             "function_name": func.__name__,
             "module": func.__module__,
             "discovery_method": "decorator",
+            "test_only": test_only,
         }
         func._function_metadata = metadata  # type: ignore
 
-        logger.debug(f"🧰 Marked function '{name}' for discovery", capability=component_of)
+        logger.debug(
+            "Debug info",
+            capability=component_of,
+            test_only=test_only,
+        )
         return func
 
     return decorator
+
+
+# 🐍🏗️🔚
