@@ -1,7 +1,10 @@
 #
-# pyvider/resources/exceptions.py
+# SPDX-FileCopyrightText: Copyright (c) 2025 provide.io llc. All rights reserved.
+# SPDX-License-Identifier: Apache-2.0
 #
 
+"""TODO: Add module docstring."""
+
 from pyvider.exceptions import PyviderError
 
 
@@ -25,4 +28,4 @@ class ResourceStateError(ResourceError):
     """Raised when resource state is invalid."""
 
 
-# 🐍🏗️
+# 🐍🏗️🔚
