@@ -1,7 +1,10 @@
 #
-# pyvider/resources/lifecycle.py
+# SPDX-FileCopyrightText: Copyright (c) 2025 provide.io llc. All rights reserved.
+# SPDX-License-Identifier: Apache-2.0
 #
 
+"""TODO: Add module docstring."""
+
 from dataclasses import dataclass
 from datetime import UTC, datetime
 from enum import Enum
@@ -36,4 +39,4 @@ class ResourceLifecycle:
         self.last_updated = datetime.now(UTC)
 
 
-# 🐍🏗️
+# 🐍🏗️🔚
