@@ -1,4 +1,10 @@
-# pyvider/resources/private_state.py
+#
+# SPDX-FileCopyrightText: Copyright (c) 2025 provide.io llc. All rights reserved.
+# SPDX-License-Identifier: Apache-2.0
+#
+
+"""TODO: Add module docstring."""
+
 from attrs import define
 
 
@@ -11,3 +17,6 @@ class PrivateState:
     """
 
     pass
+
+
+# 🐍🏗️🔚
