@@ -1,7 +1,10 @@
 #
-# pyvider/resources/protocol.py
+# SPDX-FileCopyrightText: Copyright (c) 2025 provide.io llc. All rights reserved.
+# SPDX-License-Identifier: Apache-2.0
 #
 
+"""TODO: Add module docstring."""
+
 from typing import Protocol, runtime_checkable
 
 from pyvider.common.types import ConfigType, StateType
@@ -37,4 +40,4 @@ class ResourceProtocol(Protocol[ResourceType, StateType, ConfigType]):
         ...
 
 
-# 🐍🏗️
+# 🐍🏗️🔚
