@@ -1,4 +1,10 @@
-# pyvider/schema/__init__.py
+#
+# SPDX-FileCopyrightText: Copyright (c) 2025 provide.io llc. All rights reserved.
+# SPDX-License-Identifier: Apache-2.0
+#
+
+"""TODO: Add module docstring."""
+
 from pyvider.schema.factory import (
     a_bool,
     a_dyn,
@@ -58,3 +64,5 @@ __all__ = [
     "s_provider",
     "s_resource",
 ]
+
+# 🐍🏗️🔚
