@@ -1,4 +1,10 @@
-# pyvider-schema/src/pyvider/schema/types/blocks.py
+#
+# SPDX-FileCopyrightText: Copyright (c) 2025 provide.io llc. All rights reserved.
+# SPDX-License-Identifier: Apache-2.0
+#
+
+"""TODO: Add module docstring."""
+
 from typing import TYPE_CHECKING
 
 from attrs import define, field
@@ -22,3 +28,6 @@ class PvsNestedBlock:
     description: str | None = field(default=None)
     min_items: int | None = field(default=None)
     max_items: int | None = field(default=None)
+
+
+# 🐍🏗️🔚
