@@ -1,3 +1,10 @@
+#
+# SPDX-FileCopyrightText: Copyright (c) 2025 provide.io llc. All rights reserved.
+# SPDX-License-Identifier: Apache-2.0
+#
+
+"""TODO: Add module docstring."""
+
 from enum import Enum
 
 
@@ -16,3 +23,6 @@ class NestingMode(str, Enum):
     SET = "SET"
     MAP = "MAP"
     GROUP = "GROUP"
+
+
+# 🐍🏗️🔚
